;
;Phoenix enhancements incl. high score table
;
;Phil Murray (philmurr)
;
;23/4/20 - RELEASE 1.2 (handles demo sounds better)
;
;Written in Z80 (but making sure only 8085 instructions used)
;Uses new Phoenix/Pleiads single ROM/RAM board
;Maps extra ROM to 8000-9FFF & NVRAM to A000-BFFF
;
;Saves high scores at a000-
;Saves dips at a300
;Saves dips2 at a301
;
;provides enhanced free play (attract mode in free play)
;prints free play when in free play mode
;and doesn't ask you to insert coin when in free play mode
;and prints high score sooner than when you press P1 or P2
;saves high score to NVRAM
;press Fire and Left at power-up to enter menu code
;press Fire and Left for 2 seconds during HST attract screen to enter menu code
;lets you backup scores for parties
;2 high score tables, one for with the bug, one without
;option to remove 200,000 point bug
;provides 5 position high score table and initials
;provides selectable sound in demo mode
;lets you choose how often sound in demo mode is played

;********************************************************************************************
;INTERCEPTS
;
;INTERCEPT 00A3 CD 47 80		call checkfp
;INTERCEPT 00AC C3 37 80		jp dontincredit
;INTERCEPT 00b2 C3 67 80		jp dontprint
;INTERCEPT 00ef CA c4 86		jp z,printcopyright
;INTERCEPT 00F2 CD 84 80 		call noinscoin
;INTERCEPT 011f d2 2e 80 		jp nc,attract
;INTERCEPT 2786 CD 3f 83 		call checkextralife

;Other changes
;02b0	cdf002 call #02f0	;***CHANGE TO 00 00 00 removes update high score routine
;21f9	cdc034 call #34c0	;***CHANGE TO C3 C0 34 removes jump to HS corruption routine
;21e7	ef				;***CHANGE TO #f6 move attract mode bird down 7 lines


;Reading DIPs (was #7800, now #a300)
;0162
;02d9
;0351
;14e2
;17e1

;Move big Phoenix text down
;
;1a21 30
;1a41 31
;1a61 32
;1a81 33
;1aa1 34
;1ac1 35
;1ae1 36
;1b01 37
;1b21 38

highscores: equ 0xa000		;with bug
highscores2: equ 0xa030		;without bug
highnames: equ 0xa060
highnames2: equ 0xa090
backupscores: equ 0xa100

dips: equ 0xa300
dips2: equ 0xa301
checkcoins: equ 0x0080
totalplayers: equ 0x43a2
playernum: equ 0x43a3
printout: equ 0x01ed ;print HL->DE, B times
nentpos: equ 0x4340
ypos: equ 0x4342
delaystore: equ 0x4343
scroll: equ 0x4345
fireleftcount: equ 0x4346
democounter: equ 0x4347	;counts which round of demo mode we're in (for sound)

;********************************************************************************************

;When you die, check lives left and jump to update high score if no lives left (instead of ret)

org 0x0b28
jp z,gethighplayer
ld l,0xa4
ld (hl),0
ret

;********************************************************************************************

;204K point bug - erase it (if we have switched it off)

org 0x0eb8

ld hl,0x4378					;Start of 204,000 point bug
ld a,d
cp 0x10
jp z,notnormal
ld l,0x70
notnormal: ld a,(hl)
and a
jp z,fillexplosion
inc l
inc l
inc l
inc l
ld a,(hl)
and a
jp z,fillexplosion
inc l		
inc l		
inc l	
inc l
jp p,fillexplosion			;has hl reached 4380 (score area)? If not, P flag set so jump over
ld a,(dips)				;check to see if we have switched off bug
and 128
jp z,fillexplosion			;if not, jump over fix
ld l,0x70					;reset hl to point to normal explosion area
fillexplosion: ld (hl),d
inc l
ld (hl),e
inc l
ld (hl),b
inc l
ld (hl),c
ld l,0x64
ld (hl),0xff
ld l,0xba
dec (hl)
pop hl
pop hl
jp (hl)

;********************************************************************************************

org 0

ld sp,0x4c00
ld h,0x50
ld (hl),0
call clearbanks					;Initialise RAM and sound
call menucode					;call menu code
ld hl,0x1800					;print top 3 rows of text (scores, etc.)
ld c,3						;3 rows
call 0x01d0					;and print
call printfreeplay				;print freeplay on screen (if dip switch set)

gameloop: call 0x0080				;check for credits
ld a,(0x43a2)					;number of players
and a
jp z,notinagame					;jump if zero (not currently in a game)
call 0x0400
call 0x2700
jp gameloop

notinagame: 

call demosound

call checkcred					;Check how many games available for available credits
and a							;if none
jp z,nocredits					;skip next code
call startagame					;jump to start game (FP) or press 1 or 2 to start
jp gameloop					;and back round loop

nocredits: 
call 0x00e3					;main attract mode
call printnewhs
jp gameloop

demosound:

ld a,(democounter)
ld c,a
ld a,(dips2)
and 3							;do we want sound in attract mode?
ret z							;return if not

dec a							;was a=1 (play every time)
jp z,playsound

dec a							;was a=2 (play every 2 times)
jp nz,not1to2
ld a,c
and 1
jp z,playsound
ret

not1to2:						;a=3 (play every 4 times)
ld a,c
and 3
ret nz

playsound:
call 0x27a8					;play sound

ld a,(0x43a4)					;get game mode
cp 3
jp nz,nobackground				;is it game playing?
ld a,(0x43b8)
cp 0x09						;are we in earlier stages?
call c,0x23d6					;if so, play sound

nobackground:
jp 0x3b4c						;and back to main game loop

   
;********************************************************************************************

org 0x8000			;additional ROM

;********************************************************************************************

clearbanks:
xor a
ld h,0x68			;Sound port B
ld (hl),a
ld h,0x60			;Sound port A
ld (hl),a
ld h,0x58			;Video scroll register
ld (hl),a
ld a,0x0f
ld h,0x68			;Reset Sound port B
ld (hl),a
ld h,0x60			;Reset Sound port A
ld (hl),a

call clearmem		;and clear first bank
ld h,0x50			;Video control (bank select)
ld (hl),1
call clearmem		;Clear second bank
ld h,0x50
ld (hl),0			;Set bank back to first
ret

clearmem:
ld hl,0x4bf8
ld a,0x3f
memclear: ld (hl),0
dec hl
cp h
jp nz,memclear
ret

;********************************************************************************************
	
attract:
call phst						; intercept attract screen to print high score table 
call 0x0196
jp 0x06f0

;********************************************************************************************

;Don't increase credits if in freeplay mode

dontincredit:
ld a,(dips)
and 32
ret nz			;return if in freeplay mode
ld l,0x8f
inc (hl)
ld a,(hl)
add a,0x20			;increase credits, convert to number
ld (0x4142),a		;print on screen & return
ret

;********************************************************************************************

;check if freeplay set, if so, jump to free play routine
;allow pressing 1 or 2 players to start game

checkfp:
ld a,(dips)
and 32
ret z				;return if not in freeplay mode
ld a,(0x43a2)
or a
ret nz			;return if in a game
ld hl,0x7000
ld a,(hl)
and 2
ld a,1
jp z,return
ld a,(hl)
and 4
ld a,2
ret nz
return:ld (0x438f),a
ret

;********************************************************************************************

;don't print credits if in freeplay

dontprint:
ld c,a
ld a,(dips)
and 32
ld a,c
ret nz
ld (0x4142),a
ret

;********************************************************************************************

;Print freeplay on screen

printfreeplay:
ld a,(dips)
and 32
ret z
ld hl,freeplaytext
ld de,0x4202
ld b,8
jp printout

;********************************************************************************************

;Dont print "insert coin" if set to free play.

noinscoin:
ld bc,0x0002
ld a,(dips)
and 32
ret z
ld bc,0x0060
ret

;********************************************************************************************

;check & save high scores in HST

gethighplayer:
ld hl,0x4381					;base of scores (P1 first)
ld a,(0x43a3)					;check player number - 0=P1, 1=P2
add a,a
add a,a
add a,l
ld l,a

;cp 0x85
;jp z,copybank
;jp notcopybank

;Copy P2 High score to P1 bank - I don't think this is actually needed

;copybank:
;ld de,0x4385
;ld bc,0x0301
;ld hl,0x5000
;copyloop:
;ld (hl),c
;ld a,(de)
;ld (hl),l
;ld (de),a
;inc de
;dec b
;jp nz,copyloop
;ld hl,0x4385
;notcopybank:

ld b,5
ld de,highscores+12				;start of top high score
ld a,(dips)
and 128
jp z,checkhighloop
ld de,highscores2+12

checkhighloop: push hl
push de
ld c,3
checknextdigit:
ld a,(de)
cp (hl)
jp c,higher
jp nz,nothigher
inc de
inc hl
dec c
jp nz,checknextdigit
nothigher:
pop de
pop hl
dec de
dec de
dec de
dec b
jp nz,checkhighloop
ret

higher:
pop de
pop hl
push bc
push hl

;insert score
ld de,highscores
ld hl,highscores+3
ld a,(dips)
and 128
jp z,hs1
ld de,highscores2
ld hl,highscores2+3
hs1:
dec b
jp z,savenewscore
nextposinhst:
ld c,3
movehs:
ld a,(hl)
ld (de),a
inc de
inc hl
dec c
jp nz,movehs
dec b
jp nz,nextposinhst
savenewscore:
pop hl
ld c,3
savescore:
ld a,(hl)
ld (de),a
inc de
inc hl
dec c
jp nz,savescore

;insert name
pop bc
ld de,highnames
ld hl,highnames+3
ld a,(dips)
and 128
jp z,inn1
ld de,highnames2
ld hl,highnames2+3
inn1:
dec b
jp z,savenewname
nextnameinhst:
ld c,3
movenames:
ld a,(hl)
ld (de),a
inc de
inc hl
dec c
jp nz,movenames
dec b
jp nz,nextnameinhst
savenewname:
push de
call enterinitials
pop de
ld hl,0x41b0
ld a,(hl)
ld (de),a
inc de
ld hl,0x4190
ld a,(hl)
ld (de),a
inc de
ld hl,0x4170
ld a,(hl)
ld (de),a

ld hl,spacetext
ld de,0x420a
ld b,8
call printout
ld hl,spacetext
ld de,0x42cc
ld b,21
call printout
ld hl,spacetext
ld de,0x42ae
ld b,19
call printout
ld hl,spacetext
ld de,0x41b0
ld b,3
call printout
ld hl,spacetext
ld de,0x41b1
ld b,3
jp printout

;********************************************************************************************

enterinitials:
call mutesound
call clearbg
ld hl,0x41b0
ld (nentpos),hl
ld a,(totalplayers)
dec a
jp z,noprintplayernum
ld hl,playertext
ld de,0x420a
ld b,7
call printout
ld a,(playernum)
add a,0x21
ld (0x412a),a

noprintplayernum:
ld hl,hstext
ld de,0x42cc
ld b,21
call printout
ld hl,entinittext
ld de,0x42ae
ld b,19
call printout
ld hl,bntext
ld de,0x41b0
ld b,3
call printout
ld hl,linetext
ld de,0x41b1
ld b,3
call printout

ld hl,0x1000 			;0e56=1 minute
ld (delaystore),hl
xor a
ld (scroll),a

notreleased:
call checkloop			;check coins etc.
ld hl,(delaystore)
ld a,h
or l
jp z,endit
ld a,(0x7000)			;read inputs
and 0x70				;mask off L/R/F
cp 0x70
jp nz,notreleased
released:

call checkloop			;check coins etc.
ld hl,(delaystore)
dec hl
ld (delaystore),hl
ld a,h
or l
jp z,clendit

ld hl,(nentpos)
ld a,(0x7000)			;read inputs
cpl
and 0x70				;mask off L/R/F
cp 0x40
jp z,left
cp 0x20
jp z,right
cp 0x10
jp nz,released
fire:
ld a,(hl)
ld c,a
ld de,-32
add hl,de
ld (nentpos),hl
ld a,l
cp 0x50
jp z,endit
ld a,c
ld (hl),a
jp notreleased

endit:
ret

clendit:
ld hl,0x41b0
ld (hl),43			;"-" character
ld hl,0x4190
ld (hl),43			;"-" character
ld hl,0x4170
ld (hl),43			;"-" character
ret

left:
ld a,(hl)
dec a
cp 255
jp nz,updateletter
ld a,26
jp updateletter

right:
ld a,(hl)
inc a
cp 27
jp nz,updateletter
ld a,0
jp updateletter

updateletter:
ld (hl),a
jp notreleased

;*****************************************************************

clearbg:
ld hl,0x1c00
ld de,0x4b40
ld b,32
clbloop4:
push bc
ld bc,0x201a
push de
clbloop2:
ld a,(hl)
ld (de),a
inc l
ld a,e
sub b
ld e,a
jp nc,clbloop3
dec d
clbloop3:
dec c
jp nz,clbloop2
pop de
dec de
pop bc
dec b
jp nz,clbloop4
ret

playertext:
db 16,12,1,25,5,18,0
hstext:
db 25,15,21,0,8,1,22,5,0,1,0,8,9,7,8,0,19,3,15,18,5
entinittext:
db 5,14,20,5,18,0,25,15,21,18,0,9,14,9,20,9,1,12,19
linetext:
db 43,43,43
bntext:
db 1,0,0
spacetext:
db 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

;*****************************************************************

printnewhs:
ld hl,highscores+14
ld a,(dips)
and 128
jp z,phs1
ld hl,highscores2+14
phs1:
ld de,0x4141
ld b,6
jp 0x00c4

;********************************************************************************************

; print high score table

phst:
ld de,0x4244					;first point for high score text
ld a,(de)
cp 8							;has it already been printed?
jp nz,hstnotprinted				;jump to print (and preset fire/left counter)
ld a,(0x7000)
and 80						;check for fire and left pressed in HST attract screen
ld a,0x60
jp nz,fireleftnotpressed			;if not, re-preset fire/left counter & return
ld a,(fireleftcount)
dec a
jp z,menucode2
fireleftnotpressed:
ld (fireleftcount),a
ret

hstnotprinted:
push hl
ld a,0x60
ld (fireleftcount),a				;preset fire/left counter
ld hl,highscorestext
ld b,12
call printout
ld hl,highnames+12
ld a,(dips)
and 128
jp z,hsn1
ld hl,highnames2+12
hsn1:
ld de,0x4226
ld c,5
phstl2:
push hl
push de
ld b,3
call printout					;print to screen
pop de
inc de
inc de
pop hl
dec hl
dec hl
dec hl
dec c
jp nz,phstl2

ld hl,highscores+14
ld a,(dips)
and 128
jp z,chhs1
ld hl,highscores2+14
chhs1:				
ld de,0x4106
ld c,5
phstl3:
push de
ld b,6
call 0x00c4
pop de
inc de
inc de
dec c
jp nz,phstl3
pop hl
ret

;********************************************************************************************

;Check for extra life

checkextralife:
ld a,(de)
sub (hl)
dec e
dec l
ld a,(de)
sbc a,(hl)
dec e
dec l
ld a,(de)
sbc a,(hl)
ret


;*****************************************************************
;MENU CODE


menucode:
ld a,(0x7000)					;Check for fire and left pressed
and 80						;If so
ret nz
menucode2:
call clearscreen
call clearbg

ld hl,titletext
ld de,0x4300
ld b,23
call printout
ld hl,configtext
ld de,0x42a2
ld b,18
call printout

ld hl,copywrtext
ld de,0x42a3
ld b,18
call printout

ld hl,livestext
ld de,0x4305
ld b,5
call printout
ld hl,blifetext
ld de,0x4307
ld b,10
call printout
ld hl,cointext
ld de,0x4309
ld b,7
call printout
ld hl,fptext
ld de,0x430b
ld b,9
call printout

ld hl,demosoundtext
ld de,0x430d
ld b,10
call printout

ld hl,scorebugtext
ld de,0x430f
ld b,8
call printout
ld hl,clrhsttext
ld de,0x4311
ld b,22
call printout

ld hl,backuphsttext
ld de,0x4313
ld b,18
call printout
ld hl,restorehsttext
ld de,0x4315
ld b,19
call printout

ld hl,exittext
ld de,0x4317
ld b,23
call printout
xor a
ld (ypos),a
ld hl,0x4325
ld a,0x7f
ld (hl),a
call pdips

menuloop:

menunotreleased:
call menucheckloop
ld a,(0x7000)				;read inputs
and 0x70					;mask off L/R/F
cp 0x70
jp nz,menunotreleased
menureleased:
call menucheckloop
ld a,(0x7000)				;read inputs
cpl
and 0x70					;mask off L/R/F
cp 0x40
jp z,menuup
cp 0x20
jp z,menudown
cp 0x10
jp nz,menureleased

menufire:
ld a,(ypos)
or a
jp nz,not0
ld a,(dips)
and 252
ld b,a
ld a,(dips)
and 3
inc a
and 3
or b
ld (dips),a
jp doneloop

not0:
cp 1
jp nz,not1
ld a,(dips)
and 243
ld b,a
ld a,(dips)
and 12
add a,4
and 12
or b
ld (dips),a
jp doneloop

not1:
cp 2
jp nz,not2
ld a,(dips)
xor 16
ld (dips),a
jp doneloop

not2:
cp 3
jp nz,not3
ld a,(dips)
xor 32
ld (dips),a
jp doneloop

not3:					;how often sound played in demo
cp 4
jp nz,not4
ld a,(dips2)
ld b,a
and 252
ld c,a
ld a,b
inc a
and 3
or c
ld (dips2),a
jp doneloop

not4:
cp 5
jp nz,not5
ld a,(dips)
xor 128
ld (dips),a
jp doneloop

not5:					;reset high scores
cp 6
jp nz,not6
ld a,(0x7000)
input1:
and 16				;fire only OR 144 for fire and barrier
jp nz,doneloop
ld hl,defscores
ld a,(0x7000)
and 4					;P2 start also pressed?
jp nz,resetscore
ld hl,deflowscores		;low scores for testing
resetscore:
ld de,highscores			;"with bug" high scores
ld b,15
ld a,(dips)
and 128
jp z,resetthescores
ld de,highscores2		;"without bug" high scores
resetthescores:
resscoreloop:
ld a,(hl)
ld (de),a
inc hl
inc de
dec b
jp nz,resscoreloop

ld hl,defnames
ld de,highnames
ld b,15
ld a,(dips)
and 128
jp z,resetthenames
ld de,highnames2
resetthenames:
resnameloop:
ld a,(hl)
ld (de),a
inc hl
inc de
dec b
jp nz,resnameloop

ld hl,starstext
ld de,0x4311
ld b,22
call printout
ld bc,36
rhstdel:
call menucheckloop
dec bc
ld a,b
or c
jp nz,rhstdel
ld hl,clrhsttext
ld de,0x4311
ld b,22
call printout
jp doneloop

not6:					;backup high scores
cp 7
jp nz,not7
ld a,(0x7000)
input2:
and 16				;fire only OR 144 for fire and barrier
jp nz,doneloop
ld hl,highscores
ld de,backupscores
ld b,0xff
backupscoreloop:
ld a,(hl)
ld (de),a
inc hl
inc de
dec b
jp nz,backupscoreloop

ld hl,starstext
ld de,0x4313
ld b,18
call printout
ld bc,36
backuphstdel:
call menucheckloop
dec bc
ld a,b
or c
jp nz,backuphstdel
ld hl,backuphsttext
ld de,0x4313
ld b,18
call printout
jp doneloop

not7:					;restore high scores
cp 8
jp nz,not8
ld a,(0x7000)
input3:
and 16				;fire only OR 144 for fire and barrier
jp nz,doneloop
ld hl,backupscores
ld de,highscores
ld b,0xff
restorescoreloop:
ld a,(hl)
ld (de),a
inc hl
inc de
dec b
jp nz,restorescoreloop

ld hl,starstext
ld de,0x4315
ld b,19
call printout
ld bc,36
restorehstdel:
call menucheckloop
dec bc
ld a,b
or c
jp nz,restorehstdel
ld hl,restorehsttext
ld de,0x4315
ld b,19
call printout
jp doneloop

not8:
jp 0

menuup:
ld a,(ypos)
dec a
cp 255
jp nz,menumove
ld a,9
jp menumove

menudown:
ld a,(ypos)
inc a
cp 10
jp nz,menumove
xor a

menumove:
ld b,a
ld a,(ypos)
add a,a
ld e,a
ld d,0
ld hl,0x4325
add hl,de
ld (hl),d
ld a,b
ld (ypos),a
add a,a
ld e,a
ld d,0
ld hl,0x4325
add hl,de
ld a,0x7f
ld (hl),a

doneloop:
call pdips
jp menuloop

pdips:
ld a,(dips)
and 3
add a,35
ld (0x41a5),a

ld a,(dips)
and 12
ld hl,l3k30k
jp z,pbl
ld hl,l4k40k
cp 4
jp z,pbl
ld hl,l5k50k
cp 8
jp z,pbl
ld hl,l6k60k
pbl:
ld de,0x41a7
ld b,6
call printout

ld a,(dips)
and 16
ld hl,c1c1c
jp z,pcoin
ld hl,c2c1c
pcoin:
ld de,0x41a9
ld b,14
call printout

ld a,(dips)
and 32
ld hl,freeoff
jp z,pfplay
ld hl,freeon
pfplay:
ld de,0x41ab
ld b,3
call printout

ld hl,howoften		;print how often sound is played in attract mode
ld a,(dips2)
and 3
add a,a
add a,a
add a,l
ld l,a
ld de,0x41ad
ld b,4
call printout

ld a,(dips)
and 128
ld hl,bugon
jp z,pbug
ld hl,bugoff
pbug:
ld de,0x41af
ld b,6
call printout
ret

checkloop:
call checkcoins

ld hl,scroll
dec (hl)
ld a,(hl)
ld (0x5800),a
ret

;*****************************************************************

menucheckloop:
ld h,0x78				;DIPs/Vblank signal
ld a,(hl)
and 0x80
jp z,menucheckloop		;Wait for VBlank
menucheckloop2:
ld a,(hl)
and 0x80
jp nz,menucheckloop2		;Wait for another VBlank

ld hl,scroll
dec (hl)
ld a,(hl)
ld (0x5800),a
ret

;*****************************************************************

mutesound:

ld a,0x0f
ld h,0x60
ld (hl),a			;Set sound port A
ld h,0x68
ld (hl),a			;Set sound port B

ld hl,0x438c		;store mute in sound storage #438C & 438D
ld (hl),a
inc l
ld (hl),a
ld hl,0x4350		;clear sound queues
ld b,0x30
jp 0x05d8

;********************************************************************************************

;checks for right number of credits based on coin settings, messes up if in fp mode so this fixes it

checkcred:

ld a,(dips)
and 32				;are we in freeplay mode?
ld a,(0x438f)			;all ok so just return
ret nz
ld a,(dips)			;how many credits per game (a contains number of games available)
and 16				;is it 1 game 1 credit?
ld a,(0x438f)
ret z					;return it yes
rrca    				;divide by 2 if 1 game 2 credits
and 0x0f				;mask off lower 4 bits
ret     				;and return


;*****************************************************************

startagame:
call mutesound
ld a,(dips)
and 32
jp z,0x0288
ld hl,0x43a2			;P1 or P2 game
ld a,(0x438f)
ld (hl),a
ld hl,0x438f
ld (hl),0
ld hl,spacetext			;Clear freeplay from screen
ld de,0x4202
ld b,8
call printout
jp 0x02b0				;jump to game start

;*****************************************************************

printcopyright:

call 0x0140		;clear screen
ld hl,0x1960		;PHOENIX COPYRIGHT TEXT
ld c,3
call 0x01d0		;print bottom 3 lines of text
ld a,(democounter)
inc a
ld (democounter),a
call mutesound
jp printfreeplay

;*****************************************************************

clearscreen:
ld h,0x50
ld (hl),0
ld hl,0x4000
ld bc,0x340
clsloop:
ld (hl),0
inc hl
dec bc
ld a,b
or c
jp nz,clsloop
ret

;*****************************************************************


titletext:
db 16,8,15,5,14,9,24,0,8,9,7,8,0,19,3,15,18,5,0,19,1,22,5

configtext:
db 3,15,14,6,9,7,21,18,1,20,9,15,14,0,13,5,14,21

livestext:
db 12,9,22,5,19

blifetext:
db 2,15,14,21,19,0,12,9,6,5

cointext:
db 3,15,9,14,1,7,5

fptext:
db 6,18,5,5,0,16,12,1,25

demosoundtext:
db 4,5,13,15,0,19,15,21,14,4

scorebugtext:
db 34,32,36,11,0,2,21,7

clrhsttext:
db 18,5,19,5,20,0,8,9,7,8,0,19,3,15,18,5,0,20,1,2,12,5

starstext:
db 31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31

backuphsttext:
db 2,1,3,11,21,16,0,8,9,7,8,0,19,3,15,18,5,19

restorehsttext:
db 18,5,19,20,15,18,5,0,8,9,7,8,0,19,3,15,18,5,19

exittext:
db 5,24,9,20,0,1,14,4,0,18,5,20,21,18,14,0,20,15,0,7,1,13,5

l3k30k:
db 35,11,43,35,32,11
l4k40k:
db 36,11,43,36,32,11
l5k50k:
db 37,11,43,37,32,11
l6k60k:
db 38,11,43,38,32,11

c1c1c:
db 33,3,15,9,14,0,33,3,18,5,4,9,20,0
c2c1c:
db 34,3,15,9,14,19,0,33,3,18,5,4,9,20

freeon:
db 15,14,0
freeoff:
db 15,6,6

howoften:
db 15,6,6,0,33,43,33,0,33,43,34,0,33,43,36,0

bugon:
db 1,3,20,9,22,5
bugoff:
db 6,9,24,5,4,0

defscores:
db 0x00,0x10,0x00,0x00,0x20,0x00,0x00,0x30,0x00,0x00,0x40,0x00,0x00,0x50,0x00

deflowscores:
db 0x00,0x01,0x00,0x00,0x02,0x00,0x00,0x03,0x00,0x00,0x04,0x00,0x00,0x05,0x00

defnames:
db 3,14,16,13,12,11,13,5,12,19,13,13,6,9,12


copywrtext:
db 16,8,9,12,13,21,18,18,0,36,43,34,32,0,18,33,42,34

;philmurr 4-20 R1.2
;*****************************************************************

freeplaytext: db 0x06,0x12,0x05,0x05,0x10,0x0C,0x01,0x19		; FREEPLAY text

;********************************************************************************************

highscorestext: db 0x08,0x09,0x07,0x08,0x00,0x00,0x13,0x03,0x0f,0x12,0x05,0x13

;********************************************************************************************

justtext: db "philmurr 23/4/20 PNHSS7.ASM R1.2"
